@@ -3,29 +3,30 @@ static pe_timeable Timeables;
 /*#define D_TIMEABLE(x) x /**/
 #define D_TIMEABLE(x) /**/
 
-/* BROQ
 static void db_show_timeables()
 {
-  pe_tmevent *ev;
-  ev = (pe_tmevent*) Timeables.next->self;
-  while (ev) {
-    warn("  %.2f : %s\n", ev->tm.at, SvPV(ev->base.desc, na));
-    ev = (pe_tmevent*) ev->tm.ring.next->self;
+  pe_timeable *tm = (pe_timeable*) Timeables.ring.next;
+  warn("timeables at %.2f\n", NVtime() + IntervalEpsilon);
+  while (tm->ring.self) {
+    STRLEN n_a;
+    pe_watcher *wa = (pe_watcher*) tm->ring.self;
+    pe_timeable *next = (pe_timeable*) tm->ring.next;
+    warn("  %.2f '%s'\n", tm->at, SvPV(wa->desc, n_a));
+    tm = next;
   }
 }
-*/
 
 static void pe_timeables_check() {
     pe_timeable *tm = (pe_timeable*) Timeables.ring.next;
-    double now = NVtime();
-    /*  warn("timeables at %.2f\n", now); db_show_timeables();/**/
-    while (tm->ring.self && tm->at < now) {
+    NV now = NVtime() + IntervalEpsilon;
+    /*db_show_timeables();/**/
+    while (tm->ring.self && now >= tm->at) {
 	pe_watcher *ev = (pe_watcher*) tm->ring.self;
 	pe_timeable *next = (pe_timeable*) tm->ring.next;
 	D_TIMEABLE({
 	    if (WaDEBUGx(ev) >= 4) {
 		STRLEN n_a;
-		warn("Event: timeable expire '%s'\n", SvPV(ev->base.desc, n_a));
+		warn("Event: timeable expire '%s'\n", SvPV(ev->desc, n_a));
 	    }
 	})
 	    assert(!WaSUSPEND(ev));
@@ -36,7 +37,7 @@ static void pe_timeables_check() {
     }
 }
 
-static double timeTillTimer() {
+static NV timeTillTimer() {
     pe_timeable *tm = (pe_timeable*) Timeables.ring.next;
     if (!tm->ring.self)
 	return 3600;
@@ -50,7 +51,7 @@ static void pe_timeable_start(pe_timeable *tm) {
     assert(!WaSUSPEND(ev));
     assert(PE_RING_EMPTY(&tm->ring));
     if (WaDEBUGx(ev)) {
-	double left = tm->at - NVtime();
+	NV left = tm->at - NVtime();
 	if (left < 0) {
 	    STRLEN n_a;
 	    warn("Event: timer for '%s' set to expire immediately (%.2f)",
@@ -65,6 +66,7 @@ static void pe_timeable_start(pe_timeable *tm) {
     /*warn("T:\n"); db_show_timeables();/**/
     D_TIMEABLE({
 	if (WaDEBUGx(ev) >= 4) {
+	    STRLEN n_a;
 	    warn("Event: timeable start '%s'\n", SvPV(ev->desc, n_a));
 	}
     })
@@ -81,7 +83,7 @@ static void pe_timeable_stop(pe_timeable *tm) {
     PE_RING_DETACH(&tm->ring);
 }
 
-static void pe_timeable_adjust(double delta) {
+static void pe_timeable_adjust(NV delta) {
     pe_timeable *rg = (pe_timeable*) Timeables.ring.next;
     while (rg != &Timeables) {
 	rg->at += delta;
