@@ -97,7 +97,7 @@ sub configure {
     }
 }
 
-sub data {  # assumes $self is a HASH ref
+sub private {  # assumes $self is a HASH ref
     my $self = shift;
     my $pkg = caller;
     if (@_) {
@@ -107,6 +107,15 @@ sub data {  # assumes $self is a HASH ref
     }
 }
 
+sub data {  # assumes $self is a HASH ref
+    my $self = shift;
+    if (@_) {
+	$self->{_user_data_} = shift
+    } else {
+	$self->{_user_data_};
+    }
+}
+
 sub clump {
     require Carp;
     Carp::cluck "clump is deprecated";
